@@ -1,6 +1,6 @@
 package Astro::Constants;
 # ABSTRACT: This library provides physical constants for use in Physics and Astronomy based on values from CODATA2014.
-$Astro::Constants::VERSION = '0.13';
+$Astro::Constants::VERSION = '0.14';
 use 5.006;
 use strict;
 use warnings;
@@ -19,7 +19,7 @@ Astro::Constants - This library provides physical constants for use in Physics a
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -32,13 +32,7 @@ version 0.13
 =head1 DESCRIPTION
 
 This module provides physical and mathematical constants for use
-in Astronomy and Astrophysics.  The two metric systems of units,
-MKS and CGS, are kept in two separate modules and are called by
-name explicitly.
-It allows you to choose between constants in units of
-centimetres /grams /seconds
-with B<Astro::Constants::CGS> and metres /kilograms /seconds with
-B<Astro::Constants::MKS>.
+in Astronomy and Astrophysics.
 
 The C<:long> tag imports all the constants in their long name forms
 (i.e. GRAVITATIONAL).  Useful subsets can be imported with these tags:
@@ -80,12 +74,18 @@ Trusting someone else's code does carry some risk, which you I<should> consider,
 but have you also considered the risk of doing it yourself with no one else 
 to check your work?
 
+=head3 And plus, it's B<FASTER>
+
+Benchmarking has shown that the imported constants can be more than 3 times
+faster than using variables or other constant modules because of the way
+the compiler optimizes your code.  So, if you've got a lot of calculating to do,
+this is the module to do it with.
+
 =head1 METHODS
 
 =head2 SPEED_LIGHT
 
-    2.99792458e8	MKS
-    2.99792458e10	CGS
+    299792458	MKS
 
 speed of light in a vacuum
 
@@ -94,8 +94,7 @@ as well as the alternate name C<LIGHT_SPEED> (imported using the :alternate tag
 
 =head2 BOLTZMANN
 
-    1.38064852e-23	MKS
-    1.38064852e-16	CGS
+    1.380649e-23	MKS
 
 Boltzmann's constant
 
@@ -103,8 +102,7 @@ This constant is also available using the short name C<$A_k>
 
 =head2 GRAVITATIONAL
 
-    6.67408e-11	MKS
-    6.67408e-8	CGS
+    6.67430e-11	MKS
 
 universal gravitational constant
 
@@ -112,8 +110,7 @@ This constant is also available using the short name C<$A_G>
 
 =head2 ELECTRON_VOLT
 
-    1.6021766208e-19	MKS
-    1.6021766208e-12	CGS
+    1.602176634e-19	MKS
 
 electron volt
 
@@ -121,8 +118,7 @@ This constant is also available using the short name C<$A_eV>
 
 =head2 PLANCK
 
-    6.626070040e-34	MKS
-    6.626070040e-27	CGS
+    6.62607015e-34	MKS
 
 Planck constant
 
@@ -130,18 +126,16 @@ This constant is also available using the short name C<$A_h>
 
 =head2 H_BAR
 
-    1.054571800e-34	MKS
-    1.054571800e-27	CGS
+    1.0545718176763e-34	MKS
 
-Planck's constant /2pi
+the reduced Planck constant, Planck's constant (exact) /2pi
 
 This constant is also available using the short name C<$A_hbar>
 as well as the alternate name C<HBAR> (imported using the :alternate tag for backwards compatibility)
 
 =head2 CHARGE_ELEMENTARY
 
-    1.6021766208e-19	MKS
-    4.8032046729e-10	CGS
+    1.602176634e-19	MKS
 
 electron charge (defined positive)
 
@@ -150,8 +144,7 @@ as well as the alternate name C<ELECTRON_CHARGE> (imported using the :alternate
 
 =head2 STEFAN_BOLTZMANN
 
-    5.670367e-8	MKS
-    5.670367e-5	CGS
+    5.670374419e-8	MKS
 
 Stefan-Boltzmann constant
 
@@ -160,7 +153,6 @@ This constant is also available using the short name C<$A_sigma>
 =head2 DENSITY_RADIATION
 
     7.565723e-16	MKS
-    7.565723e-15	CGS
 
 radiation density constant, 4 * sigma / c
 
@@ -169,8 +161,7 @@ as well as the alternate name C<A_RAD> (imported using the :alternate tag for ba
 
 =head2 WIEN
 
-    2.8977729e-3	MKS
-    2.8977729e-1	CGS
+    2.897771955e-3	MKS
 
 Wien wavelength displacement law constant
 
@@ -178,8 +169,7 @@ This constant is also available using the short name C<$A_Wien>
 
 =head2 ALPHA
 
-    7.2973525664e-3	MKS
-    7.2973525664e-3	CGS
+    7.2973525693e-3	MKS
 
 fine structure constant
 
@@ -196,8 +186,7 @@ as well as the alternate name C<VACUUM_IMPEDANCE> (imported using the :alternate
 
 =head2 PERMITIV_FREE_SPACE
 
-    8.854187817e-12	MKS
-    1	CGS
+    8.8541878128e-12	MKS
 
 permittivity of free space, epsilon_0, the electric constant
 
@@ -206,8 +195,7 @@ as well as the alternate name C<PERMITIVITY_0> (imported using the :alternate ta
 
 =head2 PERMEABL_FREE_SPACE
 
-    1.2566370614e-6	MKS
-    1	CGS
+    1.25663706212e-6	MKS
 
 permeability of free space, mu_0, the magnetic constant
 
@@ -233,9 +221,9 @@ as well as the alternate name C<FOURPI> (imported using the :alternate tag for b
 
 =head2 STERADIAN
 
-    57.2957795130823
+    3282.80635001174
 
-a measure of solid angle in square degrees
+a measure of solid angle in square degrees and a SI derived unit
 
 This constant is also available using the short name C<$A_ster>
 
@@ -249,17 +237,15 @@ This constant is also available using the short name C<$A_exp>
 
 =head2 ATOMIC_MASS_UNIT
 
-    1.660539040e-27	MKS
-    1.660539040e-24	CGS
+    1.66053906660e-27	MKS
 
-atomic mass unit, 1 u
+unified atomic mass unit, 1 u
 
 This constant is also available using the short name C<$A_amu>
 
 =head2 PARSEC
 
     3.08567758149e16	MKS
-    3.08567758149e18	CGS
 
 parsec
 
@@ -268,7 +254,6 @@ This constant is also available using the short name C<$A_pc>
 =head2 ASTRONOMICAL_UNIT
 
     149_597_870_700	MKS
-    1.496e13	CGS
 
 astronomical unit
 
@@ -277,7 +262,6 @@ This constant is also available using the short name C<$A_AU>
 =head2 LIGHT_YEAR
 
     9_460_730_472_580_800	MKS
-    9.4607304725808e17	CGS
 
 the distance that light travels in vacuum in one Julian year
 
@@ -286,7 +270,6 @@ This constant is also available using the short name C<$A_ly>
 =head2 ANGSTROM
 
     1e-10	MKS
-    1e-8	CGS
 
 Angstrom
 
@@ -295,15 +278,14 @@ This constant is also available using the short name C<$A_AA>
 =head2 JANSKY
 
     1e-26	MKS
-    1e-23	CGS
 
-Jansky
+Jansky, a unit of flux density
 
 This constant is also available using the short name C<$A_Jy>
 
 =head2 AVOGADRO
 
-    6.022140857e23
+    6.02214076e23
 
 Avogadro's number
 
@@ -345,7 +327,6 @@ the period between successive passages of the Sun (as seen from the geocenter) t
 =head2 MASS_SOLAR
 
     1.9884e30	MKS
-    1.9884e33	CGS
 
 solar mass
 
@@ -354,8 +335,7 @@ as well as the alternate name C<SOLAR_MASS> (imported using the :alternate tag f
 
 =head2 LUMINOSITY_SOLAR
 
-    3.846e26	MKS
-    3.846e33	CGS
+    3.828e26	MKS
 
 solar luminosity
 
@@ -364,10 +344,11 @@ as well as the alternate name C<SOLAR_LUMINOSITY> (imported using the :alternate
 
 =head2 DENSITY_CRITICAL_RHOc
 
-    1.8791e-26	MKS
-    1.8791e-29	CGS
+    1.87834e-26	MKS
 
-critical density /h^2
+Critical Density parameter expressed in terms of
+	<math>{ρ<sub>c</sub><over>h<sup>2</sup>} = {3 × (100 km s<sup>−1</sup> Mpc<sup>−1</sup>)<sup>2</sup> <over>8 π G}</math>
+	Multiply by the square of the dimensionless Hubble parameter, h, in your calculations to get the actual value
 
 This constant is also available using the short name C<$A_rhoc>
 as well as the alternate name C<RHO_C> (imported using the :alternate tag for backwards compatibility)
@@ -382,7 +363,7 @@ This constant is also available using the short name C<$A_tH>
 
 =head2 TEMPERATURE_CMB
 
-    2.725
+    2.72548
 
 cosmic microwave background temperature in Kelvin
 
@@ -393,7 +374,7 @@ as well as the alternate name C<CMB_TEMPERATURE> (imported using the :alternate
 
     -26.74
 
-solar V magnitude
+visual brightness of the Sun
 
 This constant is also available using the short name C<$A_Vsun>
 as well as the alternate name C<SOLAR_V_MAG> (imported using the :alternate tag for backwards compatibility)
@@ -410,7 +391,6 @@ as well as the alternate name C<SOLAR_V_ABS_MAG> (imported using the :alternate
 =head2 RADIUS_SOLAR
 
     6.96e8	MKS
-    6.96e10	CGS
 
 solar radius
 
@@ -420,7 +400,6 @@ as well as the alternate name C<SOLAR_RADIUS> (imported using the :alternate tag
 =head2 MASS_EARTH
 
     5.9722e24	MKS
-    5.9722e27	CGS
 
 mass of Earth
 
@@ -430,7 +409,6 @@ as well as the alternate name C<EARTH_MASS> (imported using the :alternate tag f
 =head2 RADIUS_EARTH
 
     6.378_136_6e6	MKS
-    6.378_136_6e8	CGS
 
 radius of Earth
 
@@ -439,9 +417,9 @@ as well as the alternate name C<EARTH_RADIUS> (imported using the :alternate tag
 
 =head2 TEMPERATURE_SOLAR_SURFACE
 
-    5778
+    5772
 
-surface temperature of sun
+surface temperature of sun (photosphere)
 
 This constant is also available using the short name C<$A_Tsun>
 as well as the alternate name C<SOLAR_TEMPERATURE> (imported using the :alternate tag for backwards compatibility)
@@ -449,7 +427,6 @@ as well as the alternate name C<SOLAR_TEMPERATURE> (imported using the :alternat
 =head2 DENSITY_SOLAR
 
     1408	MKS
-    1.408	CGS
 
 mean solar density
 
@@ -458,8 +435,7 @@ as well as the alternate name C<SOLAR_DENSITY> (imported using the :alternate ta
 
 =head2 DENSITY_EARTH
 
-    5514	MKS
-    5.514	CGS
+    5515	MKS
 
 mean Earth density
 
@@ -468,8 +444,7 @@ as well as the alternate name C<EARTH_DENSITY> (imported using the :alternate ta
 
 =head2 GRAVITY_SOLAR
 
-    274.0	MKS
-    27400	CGS
+    274.78	MKS
 
 solar surface gravity
 
@@ -478,8 +453,7 @@ as well as the alternate name C<SOLAR_GRAVITY> (imported using the :alternate ta
 
 =head2 GRAVITY_EARTH
 
-    9.78	MKS
-    978	CGS
+    9.80665	MKS
 
 Earth surface gravity
 
@@ -489,7 +463,6 @@ as well as the alternate name C<EARTH_GRAVITY> (imported using the :alternate ta
 =head2 RADIUS_LUNAR
 
     1.7381e6	MKS
-    1.7381e8	CGS
 
 lunar radius
 
@@ -498,8 +471,7 @@ as well as the alternate name C<LUNAR_RADIUS> (imported using the :alternate tag
 
 =head2 MASS_LUNAR
 
-    7.342e22	MKS
-    7.342e25	CGS
+    7.346e22	MKS
 
 lunar mass
 
@@ -508,8 +480,7 @@ as well as the alternate name C<LUNAR_MASS> (imported using the :alternate tag f
 
 =head2 AXIS_SM_LUNAR
 
-    3.844e8	MKS
-    3.844e10	CGS
+    3.84402e8	MKS
 
 lunar orbital semi-major axis
 
@@ -527,8 +498,7 @@ as well as the alternate name C<LUNAR_ECCENTRICITY> (imported using the :alterna
 
 =head2 THOMSON_CROSS_SECTION
 
-    6.6524587158e-29	MKS
-    6.6524587158e-25	CGS
+    6.6524587321e-29	MKS
 
 Thomson cross-section
 
@@ -537,8 +507,7 @@ as well as the alternate name C<THOMSON_XSECTION> (imported using the :alternate
 
 =head2 MASS_ELECTRON
 
-    9.10938356e-31	MKS
-    9.10938356e-28	CGS
+    9.1093837015e-31	MKS
 
 mass of electron
 
@@ -547,8 +516,7 @@ as well as the alternate name C<ELECTRON_MASS> (imported using the :alternate ta
 
 =head2 MASS_PROTON
 
-    1.672621898e-27	MKS
-    1.672621898e-24	CGS
+    1.67262192369e-27	MKS
 
 mass of proton
 
@@ -557,8 +525,7 @@ as well as the alternate name C<PROTON_MASS> (imported using the :alternate tag
 
 =head2 MASS_NEUTRON
 
-    1.674927471e-27	MKS
-    1.674927471e-24	CGS
+    1.67492749804e-27	MKS
 
 neutron mass
 
@@ -577,7 +544,7 @@ as well as the alternate name C<HYDROGEN_MASS> (imported using the :alternate ta
 
 =head2 MASS_ALPHA
 
-    6.644_657_230e-27
+    6.6446573357e-27
 
 mass of alpha particle
 
@@ -585,8 +552,7 @@ This constant is also available using the short name C<$A_ma>
 
 =head2 RADIUS_ELECTRON
 
-    2.8179403227e-15	MKS
-    2.8179403227e-13	CGS
+    2.8179403262e-15	MKS
 
 classical electron radius
 
@@ -595,8 +561,7 @@ as well as the alternate name C<ELECTRON_RADIUS> (imported using the :alternate
 
 =head2 RADIUS_BOHR
 
-    5.2917721067e-11	MKS
-    5.2917721067e-9	CGS
+    5.29177210903e-11	MKS
 
 Bohr radius
 
