@@ -30,7 +30,7 @@ write_module_header($cgs_fh, 'Astro::Constants::CGS');
 write_pod_synopsis($ac_fh);
 
 for my $constant ( $xml->getElementsByTagName('PhysicalConstant') ) {
-	my ($short_name, $long_name, $mks_value, $cgs_value, $values, ) = undef;
+	my ($short_name, $long_name, $mks_value, $cgs_value, $values, $options, ) = undef;
 
 	for my $name ( $constant->getChildrenByTagName('name') ) {
 		$short_name = $name->textContent() if $name->getAttribute('type') eq 'short';
@@ -72,10 +72,11 @@ for my $constant ( $xml->getElementsByTagName('PhysicalConstant') ) {
 				if $values->{cgs} || $values->{value};
 		}
 	}
+	$options->{deprecated} = 1 if $constant->getChildrenByTagName('deprecated');
 
 	#### write to the module files
 	write_method_pod($ac_fh, $long_name, $short_name, $description, $values, \@alternates);
-	write_constant($mks_fh, ($values->{mks} || $values->{value}), $long_name, $short_name) 
+	write_constant($mks_fh, ($values->{mks} || $values->{value}), $long_name, $short_name, $options) 
 			if $values->{mks} || $values->{value};
 	write_constant($cgs_fh, ($values->{cgs} || $values->{value}), $long_name, $short_name) 
 			if $values->{cgs} || $values->{value};
@@ -123,8 +124,6 @@ HEADER
 		print $fh "use base qw/Exporter/;\n\n";
 	}
 	if ($name eq 'Astro::Constants::CGS') {
-		print $fh qq(warn "use of $name is deprecated and will be removed from the package in version 0.15";\n);
-		print $fh qq(warn "write new code to use Astro::Constants::MKS instead";\n\n);
 		print $fh <<"NOTICE";
 warn "use of $name is deprecated and will be removed from the package in version 0.15";
 warn "write new code to use Astro::Constants::MKS instead";
@@ -194,7 +193,6 @@ sub write_method_pod {
 
 	my $display;
 	$display .= "    $values->{mks}\tMKS\n" if $values->{mks};
-	$display .= "    $values->{cgs}\tCGS\n" if $values->{cgs};
 	$display ||= "    $values->{value}\n";
 
 	say $fh <<"POD";	# writing for Dist::Zilla enhanced Pod
@@ -239,13 +237,7 @@ sub write_pod_synopsis {
 =head1 DESCRIPTION
 
 This module provides physical and mathematical constants for use
-in Astronomy and Astrophysics.  The two metric systems of units,
-MKS and CGS, are kept in two separate modules and are called by
-name explicitly.
-It allows you to choose between constants in units of
-centimetres /grams /seconds
-with B<Astro::Constants::CGS> and metres /kilograms /seconds with
-B<Astro::Constants::MKS>.
+in Astronomy and Astrophysics.
 
 The C<:long> tag imports all the constants in their long name forms
 (i.e. GRAVITATIONAL).  Useful subsets can be imported with these tags:
@@ -287,6 +279,13 @@ Trusting someone else's code does carry some risk, which you I<should> consider,
 but have you also considered the risk of doing it yourself with no one else 
 to check your work?
 
+=head3 And plus, it's B<FASTER>
+
+Benchmarking has shown that the imported constants can be more than 3 times
+faster than using variables or other constant modules because of the way
+the compiler optimizes your code.  So, if you've got a lot of calculating to do,
+this is the module to do it with.
+
 =head1 EXPORT
 
 Nothing is exported by default, so the module doesn't clobber any of your variables.  
@@ -441,16 +440,27 @@ POD
 }
 
 sub write_constant {
-	my ($fh, $value, $long_name, $short_name) = @_;
+	my ($fh, $value, $long_name, $short_name, $options) = @_;
 
-	say $fh "use constant $long_name => $value;";
-	say $fh "\*$short_name = \\$value;" if $short_name;
+	if ($options && $options->{deprecated}) {
+		print $fh <<"WARNING";
+sub $long_name { warn "$long_name deprecated"; return $value; }
+WARNING
+	}
+	else {
+		say $fh "use constant $long_name => $value;";
+		say $fh "\*$short_name = \\$value;" if $short_name;
+	}
 }
 
 my %precision;
 sub store_precision {
 	my ($name, $precision, $type) = @_;
 
+	if ($type eq 'defined') {
+		$type = 'relative';
+		$precision = 0;
+	}
 	$precision{$name}->{value} = $precision;
 	$precision{$name}->{type} = $type;
 }
